@@ -3,10 +3,6 @@
 # Version 1.0
 # Licence GPL v3
 
-if (!isGeneric("as.data.frame")) {
-	setGeneric("as.data.frame", function(x, row.names = NULL, optional = FALSE, ...)
-		standardGeneric("as.data.frame"))
-}	
 
 
 .insertColsInDF <- function(x, y, col, combinenames=TRUE) {
@@ -48,9 +44,9 @@ setMethod('as.data.frame', signature(x='Raster'),
 				end <- start + tr$nrows[i] * ncx - 1
 				vv <- cbind(start:end, getValues(x, row=tr$row[i], nrows=tr$nrows[i]))
 				if (xy) {
-					XY <- data.frame(xyFromCell(r, start:end))
-					vv <- stats::na.omit(vv, XY)
+					vv <- cbind(vv, data.frame(xyFromCell(r, start:end)))
 				}
+				vv <- stats::na.omit(vv)
 				v <- rbind(v, vv)
 				pbStep(pb, i) 	
 			}
@@ -106,7 +102,7 @@ setMethod('as.data.frame', signature(x='Raster'),
 				times <- names(x)
 				timevar <- 'layer'
 			} 
-			v <- reshape(v, direction='long', varying=nc, v.names='value', timevar=timevar, times=times)	
+			v <- stats::reshape(v, direction='long', varying=nc, v.names='value', timevar=timevar, times=times)	
 			v[ncol(v)] = NULL  # id column
 			rownames(v) <- NULL
 			#v$layer <- names(x)[v$layer]
