@@ -4,50 +4,142 @@
 # Licence GPL v3
 
 
+
 ### from terra
-#setAs("SpatRaster", "Raster", 
-#	function(from) {
-#		s <- sources(from)
-#		nl <- nlyr(from)
-#		e <- as.vector(ext(from))
-#		prj <- crs(from)
-#		if (nl == 1) {
-#			if (s$source == "") {
-#				r <- raster::raster(ncols=ncol(from), nrows=nrow(from), crs=crs(from),
-#			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
-#				if (hasValues(from)) {
-#					raster::values(r) <- values(from)
-#				}
-#			} else {
-#				r <- raster::raster(s$source)
-#			}
-#			names(r) <- names(from)
-#		} else {
-#			if (nrow(s) == 1 & s$source[1] != "") {
-#				r <- raster::brick(s$source)
-#			} else if (all(s$source=="")) {
-#				r <- raster::brick(ncol=ncol(from), nrow=nrow(from), crs=prj,
-#			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4], nl=nlyr(from))
-#				if (hasValues(from)) {
-#					raster::values(r) <- values(from)
-#				}
-#			} else {
-#				x <- raster::raster(ncol=ncol(from), nrow=nrow(from), crs=prj,
-#			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
-#				r <- list()
-#				for (i in 1:nl) {
-#					if (s$source[i] == "") {
-#						r[[i]] <- raster::setValues(x, values(from[[i]]))
-#					} else {
-#						r[[i]] <- raster::raster(s$source[i])
-#					}
-#				}
-#				r <- raster::stack(r)
-#			}
-#		}
-#		return(r)
-#	}
-#)
+setAs("SpatRaster", "Raster", 
+	function(from) {
+		b <- sources(from, bands=TRUE)
+		nl <- nlyr(from)
+		e <- as.vector(ext(from))
+		prj <- crs(from)
+		if (nl == 1) {
+			if (b$source == "") {
+				r <- raster::raster(ncols=ncol(from), nrows=nrow(from), crs=crs(from),
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
+				if (hasValues(from)) {
+					raster::values(r) <- values(from)
+				}
+			} else {
+				r <- raster::raster(b$source, band=b$bands)
+			}
+		} else {
+			if ((nrow(b) == 1) & (b$source[1] != "")) {
+				r <- raster::brick(b$source)
+				if (!((raster::nlayers(r) == nl) && (b$bands[1] == 1) && (all(diff(b$bands) == 1)))) {
+					r <- raster::stack(b$source, bands=b$bands)
+				}
+			} else if (all(b$source=="")) {
+				r <- raster::brick(ncol=ncol(from), nrow=nrow(from), crs=prj,
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4], nl=nlyr(from))
+				if (hasValues(from)) {
+					raster::values(r) <- values(from)
+				}
+			} else {
+				x <- raster::raster(ncol=ncol(from), nrow=nrow(from), crs=prj,
+			          xmn=e[1], xmx=e[2], ymn=e[3], ymx=e[4])
+				r <- list()
+				for (i in 1:nl) {
+					if (b$source[i] == "") {
+						r[[i]] <- raster::setValues(x, values(from[[i]]))
+					} else {
+						bands <- b$bands[b$sid == i]
+						r[[i]] <- raster::stack(b$source[i], bands=bands)
+					}
+				}
+				r <- raster::stack(r)
+			}
+		}
+		try(levels(r) <- cats(from), silent=TRUE)
+		try(names(r) <- names(from))
+		return(r)
+	}
+)
+
+
+
+## to terra
+
+.fromRasterLayerBrick <- function(from) {
+	 
+	if (raster::fromDisk(from)) {
+		f <- raster::filename(from)
+		if (from@file@driver == "netcdf") {
+			v <- attr(from@data, "zvar")
+			r <- rast(f, v)	
+		} else {
+			r <- try(rast(f), silent=TRUE)
+			if (inherits(r, "try-error")) {
+				r <- rast(from + 0)
+				levs <- levels(from)[[1]]
+				if (!is.null(levs)) {
+					levels(r) <- levs
+				}
+			}
+			crs(r) <- raster::wkt(from)
+		}
+		if (from@file@NAchanged) {
+			NAflag(r) <- from@file@nodatavalue
+		}
+	} else {
+		crsobj <- from@crs
+		if (is.na(crsobj)) {
+			prj <- ""
+		} else {
+			crscom <- comment(crsobj)
+			if (is.null(crscom)) {
+				prj <- crsobj@projargs
+			} else {
+				prj <- crscom
+			}
+		}
+		r <- rast(	nrows=nrow(from), 
+					ncols=ncol(from),
+					nlyrs=raster::nlayers(from),
+					crs=prj,
+					extent=raster::extent(from))
+		if (raster::hasValues(from)) {
+			values(r) <- values(from)
+		}
+		levs <- levels(from)[[1]]
+		if (!is.null(levs)) {
+			levels(r) <- levs				
+		}
+	}
+	names(r)  <- names(from)
+	r
+}
+
+.fromRasterStack <- function(from) {
+	x <- from[[1]]
+	n <- raster::nbands(x)
+	nl <- raster::nlayers(from)
+	if ((n > 1) & (n == nl)) {
+		ff <- lapply(1:nl, function(i) { raster::filename(from[[i]]) })
+		if (length(unique(ff)) == 1) {
+			r <- rast(raster::filename(x))
+			return(r)
+		}
+	} 
+	s <- lapply(1:raster::nlayers(from), function(i) {
+		x <- from[[i]]
+		.fromRasterLayerBrick(x)[[raster::bandnr(x)]]
+	})
+	s <- do.call(c, s)
+	names(s) <- names(from)
+	s
+}
+
+
+setAs("Raster", "SpatRaster", 
+	function(from) {
+		if (inherits(from, "RasterLayer") || inherits(from, "RasterBrick")) { 
+			.fromRasterLayerBrick(from)
+		} else {
+			.fromRasterStack(from)
+		}
+	}
+)
+
 
 
 
