@@ -4,7 +4,6 @@
 # Licence GPL v3
 
 
-
 .pointsToRaster <- function(xy, r, field, fun='last', background=NA, mask=FALSE, update=FALSE, updateValue='all', filename="", na.rm=TRUE, ...) {
 
 	rs <- raster(r)
@@ -38,7 +37,12 @@
 		} else {
 			if (na.rm) {
 				if (fun == 'first') {
-					fun <- function(x, ...) { stats::na.omit(x[1]) }
+					fun <- function(x, ...) { 
+						# stats::na.omit(x[1]) 
+						# fix by Daniel Schlapfer
+							stats::na.omit(x)[1]
+						}
+						
 				} else if (fun == 'last') {
 					fun <- function(x, ...) { x <- stats::na.omit(x); x[length(x)] }
 				} else if (fun == 'count') {
@@ -48,7 +52,17 @@
 				if (fun == 'first') {
 					fun <- function(x, ...) { x[1] }
 				} else if (fun == 'last') {
-					fun <- function(x, ...) { x[length(x)] }
+					fun <- function(x, ...) { 
+						# x[length(x)] 
+						# fix by Daniel Schlapfer
+						x <- stats::na.omit(x)
+						if (length(x) > 0) {
+							x[length(x)]
+						} else { 
+							NA
+						}
+
+					}
 				} else if (fun == 'count') {
 					fun <- function(x, ...) length(x)
 				}
