@@ -3,10 +3,6 @@
 # Version 1.0
 # Licence GPL v3
 
-if (!isGeneric('writeRaster')) {
-	setGeneric('writeRaster', function(x, filename, ...)
-		standardGeneric('writeRaster')) 
-}
 
 
 setMethod('writeRaster', signature(x='RasterLayer', filename='character'), 
@@ -211,8 +207,8 @@ function(x, filename, format, bylayer=FALSE, suffix='numbers', ...) {
 			b <- brick(x, values=FALSE)
 			b@z  <- x@z
 			b <- .startWriteCDF(b, filename=filename,  ...)
-			x <- .writeValuesBrickCDF(b, x@data@values)	
-			x <- .stopWriteCDF(x) 
+			b <- .writeValuesBrickCDF(b, values(x))	
+			x <- .stopWriteCDF(b) 
 		} else {
 			x <- .writeGDALall(x, filename=filename, format=filetype, ...) 
 		}
